@@ -3,6 +3,6 @@ package test;
 public interface Component5
 {
 
-    public String printNew();
+    public String printOld();
 
 }
